@@ -645,10 +645,10 @@ class CythonCompileTestCase(unittest.TestCase):
             (name, getattr(Options, name))
             for name in ('warning_errors', 'clear_to_none', 'error_on_unknown_names', 'error_on_uninitialized')
         ]
-        self._saved_default_directives = list(Options.directive_defaults.items())
+        self._saved_default_directives = list(Options.get_directive_defaults().items())
         Options.warning_errors = self.warning_errors
         if sys.version_info >= (3, 4):
-            Options.directive_defaults['autotestdict'] = False
+            Options._directive_defaults['autotestdict'] = False
 
         if not os.path.exists(self.workdir):
             os.makedirs(self.workdir)
@@ -659,7 +659,7 @@ class CythonCompileTestCase(unittest.TestCase):
         from Cython.Compiler import Options
         for name, value in self._saved_options:
             setattr(Options, name, value)
-        Options.directive_defaults = dict(self._saved_default_directives)
+        Options._directive_defaults = dict(self._saved_default_directives)
         unpatch_inspect_isfunction()
 
         try:
@@ -1197,7 +1197,7 @@ class CythonPyregrTestCase(CythonRunTestCase):
         from Cython.Compiler import Options
         Options.error_on_unknown_names = False
         Options.error_on_uninitialized = False
-        Options.directive_defaults.update(dict(
+        Options._directive_defaults.update(dict(
             binding=True, always_allow_keywords=True,
             set_initial_path="SOURCEFILE"))
         patch_inspect_isfunction()
@@ -1667,6 +1667,14 @@ def main():
     global DISTDIR, WITH_CYTHON
     DISTDIR = os.path.join(os.getcwd(), os.path.dirname(sys.argv[0]))
 
+    from Cython.Compiler import DebugFlags
+    args = []
+    for arg in sys.argv[1:]:
+        if arg.startswith('--debug') and arg[2:].replace('-', '_') in dir(DebugFlags):
+            setattr(DebugFlags, arg[2:].replace('-', '_'), True)
+        else:
+            args.append(arg)
+
     from optparse import OptionParser
     parser = OptionParser()
     parser.add_option("--no-cleanup", dest="cleanup_workdir",
@@ -1756,7 +1764,7 @@ def main():
                       help="exit without error code even on test failures")
     parser.add_option("--root-dir", dest="root_dir", default=os.path.join(DISTDIR, 'tests'),
                       help="working directory")
-    parser.add_option("--work-dir", dest="work_dir", default=os.path.join(os.getcwd(), 'BUILD'),
+    parser.add_option("--work-dir", dest="work_dir", default=os.path.join(os.getcwd(), 'TEST_TMP'),
                       help="working directory")
     parser.add_option("--cython-dir", dest="cython_dir", default=os.getcwd(),
                       help="Cython installation directory (default: use local source version)")
@@ -1769,7 +1777,7 @@ def main():
     parser.add_option("--use_common_utility_dir", default=False, action="store_true")
     parser.add_option("--use_formal_grammar", default=False, action="store_true")
 
-    options, cmd_args = parser.parse_args()
+    options, cmd_args = parser.parse_args(args)
 
     WORKDIR = os.path.abspath(options.work_dir)
 
